package http

import (
	"net/http"

	"git.javil.eu/jacob1123/budgeteer/postgres"
	"github.com/gin-gonic/gin"
	"github.com/google/uuid"
)

type AccountData struct {
	AlwaysNeededData
	Account      *postgres.Account
	Categories   []postgres.GetCategoriesRow
	Transactions []postgres.GetTransactionsForAccountRow
}

func (h *Handler) account(c *gin.Context) {
	data := c.MustGet("data").(AlwaysNeededData)

	accountID := c.Param("accountid")
	accountUUID, err := uuid.Parse(accountID)
	if err != nil {
		c.Redirect(http.StatusTemporaryRedirect, "/login")
		return
	}

	account, err := h.Service.GetAccount(c.Request.Context(), accountUUID)
	if err != nil {
		c.AbortWithError(http.StatusNotFound, err)
		return
	}

	categories, err := h.Service.GetCategories(c.Request.Context(), data.Budget.ID)
	if err != nil {
		c.AbortWithError(http.StatusNotFound, err)
		return
	}

	transactions, err := h.Service.GetTransactionsForAccount(c.Request.Context(), accountUUID)
	if err != nil {
		c.AbortWithError(http.StatusNotFound, err)
		return
	}

	d := AccountData{
		data,
		&account,
		categories,
		transactions,
	}

	c.HTML(http.StatusOK, "account.html", d)
}

func (h *Handler) transactionsForAccount(c *gin.Context) {
	accountID := c.Param("accountid")
	accountUUID, err := uuid.Parse(accountID)
	if err != nil {
		c.AbortWithError(http.StatusBadRequest, err)
		return
	}

	account, err := h.Service.GetAccount(c.Request.Context(), accountUUID)
	if err != nil {
		c.AbortWithError(http.StatusNotFound, err)
		return
	}

	transactions, err := h.Service.GetTransactionsForAccount(c.Request.Context(), accountUUID)
	if err != nil {
		c.AbortWithError(http.StatusNotFound, err)
		return
	}

	c.JSON(http.StatusOK, struct {
		Account      postgres.Account
		Transactions []postgres.GetTransactionsForAccountRow
	}{account, transactions})
}
