package http

import (
	"fmt"
	"net/http"

	"git.javil.eu/jacob1123/budgeteer/postgres"
	"github.com/gin-gonic/gin"
	"github.com/google/uuid"
)

type AlwaysNeededData struct {
	Budget   postgres.Budget
	Accounts []postgres.GetAccountsWithBalanceRow
}

func (h *Handler) getImportantData(c *gin.Context) {
	budgetID := c.Param("budgetid")
	budgetUUID, err := uuid.Parse(budgetID)
	if err != nil {
		c.AbortWithError(http.StatusBadRequest, fmt.Errorf("budgetid missing from URL"))
		return
	}

	budget, err := h.Service.GetBudget(c.Request.Context(), budgetUUID)
	if err != nil {
		c.AbortWithError(http.StatusNotFound, err)
		return
	}

	accounts, err := h.Service.GetAccountsWithBalance(c.Request.Context(), budgetUUID)
	if err != nil {
		c.AbortWithError(http.StatusInternalServerError, err)
		return
	}

	base := AlwaysNeededData{
		Accounts: accounts,
		Budget:   budget,
	}

	c.Set("data", base)
	c.Next()
}
