package postgres

import (
	"context"
	"database/sql"
	"fmt"

	"github.com/google/uuid"
)

// NewBudget creates a budget and adds it to the current user
func (s *Database) NewBudget(context context.Context, name string, userID uuid.UUID) (*Budget, error) {
	tx, err := s.BeginTx(context, &sql.TxOptions{})
	q := s.WithTx(tx)
	budget, err := q.CreateBudget(context, CreateBudgetParams{
		Name:             name,
		IncomeCategoryID: uuid.New(),
	})
	if err != nil {
		return nil, fmt.Errorf("create budget: %w", err)
	}

	ub := LinkBudgetToUserParams{UserID: userID, BudgetID: budget.ID}
	_, err = q.LinkBudgetToUser(context, ub)
	if err != nil {
		return nil, fmt.Errorf("link budget to user: %w", err)
	}

	group, err := q.CreateCategoryGroup(context, CreateCategoryGroupParams{
		Name:     "Inflow",
		BudgetID: budget.ID,
	})
	if err != nil {
		return nil, fmt.Errorf("create inflow category_group: %w", err)
	}

	cat, err := q.CreateCategory(context, CreateCategoryParams{
		Name:            "Ready to Assign",
		CategoryGroupID: group.ID,
	})
	if err != nil {
		return nil, fmt.Errorf("create ready to assign category: %w", err)
	}

	err = q.SetInflowCategory(context, SetInflowCategoryParams{
		IncomeCategoryID: cat.ID,
		ID:               budget.ID,
	})
	if err != nil {
		return nil, fmt.Errorf("set inflow category: %w", err)
	}

	tx.Commit()

	return &budget, nil
}
