const budget = {
    state () {
        return {
                Accounts: [],
                CurrentAccount: null,
                Categories: [],
                Transactions: [],
                Assignments: []
        }
    },
    mutations: {
        setAccounts (state, accounts) {
            state.Accounts = accounts;
        },
        setCurrentAccount(state, account) {
            state.CurrentAccount = account;
        },
        setTransactions(state, transactions){
            state.Transactions = transactions;
        }
    },
    getters: {
        Accounts(state) {
            return state.Accounts || [];
        },
        CurrentAccount(state) {
            return state.CurrentAccount || {};
        },
        OnBudgetAccounts(state) {
            return (state.Accounts || []).filter(x => x.OnBudget);
        },
        OffBudgetAccounts(state) {
            return (state.Accounts || []).filter(x => !x.OnBudget);
        },
        Transactions(state) {
            return (state.Transactions || []);
        }
    },
    actions: {
        async fetchBudget ({state, commit, rootState}, budgetid) {
            const result = await fetch("/api/v1/budget/" + budgetid, {
                headers: {
                    'Authorization': 'Bearer ' + rootState.Session.Token
                }
            });
            const response = await result.json();
            return commit("setAccounts", response.Accounts);
        },
        async fetchAccount ({state, commit, rootState}, accountid) {
            const result = await fetch("/api/v1/account/" + accountid + "/transactions", {
                headers: {
                    'Authorization': 'Bearer ' + rootState.Session.Token
                }
            });
            const response = await result.json();
            return commit("setTransactions", response.Transactions);
        },
        async setCurrentAccount({state, commit, dispatch}, {budgetid, accountid}) {
            await dispatch("fetchBudget", budgetid);
            for (const element of state.Accounts) {
                if(element.ID != accountid) 
                    continue
                
                commit("setCurrentAccount", element);
                commit("setTitle", element.Name);
                break
            }
        }
    }
}

export default budget