const dashboard = {
    state () {
        return {
            Budgets: [],
            CurrentBudget: null,
        }
    },
    mutations: {
        setBudgets (state, budgets) {
            state.Budgets = budgets;
        },
        addBudget(state, budget) {
            state.Budgets.push(budget);
        },
        setCurrentBudget(state, budget) {
            state.CurrentBudget = budget;
        }
    },
    getters: {
        Budgets(state) {
            return state.Budgets || [];
        },
        CurrentBudget(state) {
            return state.CurrentBudget || {};
        }
    },
    actions: {
        async fetchDashboard ({state, commit, rootState}) {
            const response = await fetch("/api/v1/dashboard", {
                headers: {
                    'Authorization': 'Bearer ' + rootState.Session.Token
                }
            })
            const data = await response.json();
            commit("setBudgets", data.Budgets);
        },
        async newBudget ({state, commit, rootState}, budgetName) {
            fetch("/api/v1/budget/new", {
                method: "POST",
                body: JSON.stringify({name: budgetName}),
                headers: {
                    'Authorization': 'Bearer ' + rootState.Session.Token
                }
            })
                .then(x => x.json())
                .then(x => commit("addBudget", x));
        },
        async setCurrentBudget({state, commit, dispatch}, budgetid) {
            await dispatch("fetchDashboard");
            for (const element of state.Budgets) {
                if(element.ID != budgetid) 
                    continue
                
                commit("setCurrentBudget", element);
                break
            }
        }
    }
}

export default dashboard