import { createStore } from 'vuex'
import dashboard from './dashboard/index'
import budget from './budget/index'

const store = createStore({
    state () {
        return {
            Session: {
                Token: null,
                User: null
            },
        }
    },
    mutations: {
        initializeStore(state) {
            let store = localStorage.getItem("store");
            if(store){
                this.replaceState(
                    Object.assign(state, JSON.parse(store))
                );
            }
        },
        setTitle (state, title) {
            document.title = "Budgeteer - " + title;
        },
        setToken(state, token) {
            state.Session.Token = token;
        }
    },
    actions: {
        logout({state, commit, rootState}){
            commit("setToken", null);
        }
    },
    modules: {
        dashboard,
        budget
    }
})

store.subscribe((mutation, state) => {
    switch(mutation.type){
        case "setCurrentBudget":
            store.dispatch("fetchBudget", mutation.payload.ID)
            break;
        case "setCurrentAccount":
            store.dispatch("fetchAccount", mutation.payload.ID)
            break;
    }
})

store.subscribe((mutation, state) => {
    let persistedState = {
        Session: state.Session,
        Budgets: state.Budgets,
        CurrentBudget: state.CurrentBudget
    }
    localStorage.setItem("store", JSON.stringify(persistedState));
})

export default store